use iced::pure::widget::{Button, Column, Container, Text};
use iced::pure::Sandbox;

pub struct Selector {
    count: i32,
    selected: Vec<String>,
}

#[derive(Debug, Clone, Copy)]
pub enum SelectorMessage {
    Select,
    Deselect,
}

impl Sandbox for Selector {
    type Message = SelectorMessage;

    fn new() -> Self {
        Selector { count: 0, selected: vec![] }
    }

    fn title(&self) -> String {
        String::from("RustyBeans")
    }

    fn update(&mut self, message: Self::Message) {
        match message {
            SelectorMessage::Select => self.count += 1,
            SelectorMessage::Deselect => self.count -= 1,
        }
    }

    fn view(&self) -> iced::pure::Element<'_, Self::Message> {
        let label = Text::new(format!("Count: {}", self.count));

        let incr = Button::new("Increment").on_press(SelectorMessage::Select);
        let decr = Button::new("Decrement").on_press(SelectorMessage::Deselect);

        let col = Column::new().push(incr).push(label).push(decr);

        Container::new(col)
            .center_x()
            .center_y()
            .width(iced::Length::Fill)
            .height(iced::Length::Fill)
            .into()
    }
}
