mod config;
mod database;
mod flow_profile;
mod plot;
mod sheets;
mod time;
mod ui;

use ui::Ui;

use std::panic;

use eframe::egui;

#[cfg(not(target_arch = "wasm32"))]
fn main() -> eframe::Result<()> {
    env_logger::init();

    let options = eframe::NativeOptions {
        drag_and_drop_support: true,
        min_window_size: Some(egui::vec2(640.0, 360.0)),
        initial_window_size: Some(egui::vec2(640.0, 360.0)),
        ..Default::default()
    };
    eframe::run_native(
        "RustyBeans",
        options,
        Box::new(|_cc| Box::new(Ui::default())),
    )
}

#[cfg(target_arch = "wasm32")]
fn main() {
    eframe::WebLogger::init(log::LevelFilter::Debug).ok();

    let options = eframe::WebOptions::default();

    wasm_bindgen_futures::spawn_local(async {
        eframe::WebRunner::new()
            .start(
                "RustyBeans",
                options,
                Box::new(|cc| Box::new(Ui::default())),
            )
            .await
            .expect("Failed to start eframe");
    });
}
