use chrono::{Duration, NaiveDateTime, NaiveTime};

pub fn str_to_naivetime(unix_str: &str) -> NaiveTime {
    NaiveTime::parse_from_str(unix_str, "%T%.3f").expect("Couldn't parse timestamp")
}

pub fn cell_to_naivetime(cell: Option<&str>) -> NaiveTime {
    str_to_naivetime(cell.expect("Timestamp is not a string!"))
}

pub fn deltatime(time: NaiveTime, start: NaiveTime) -> Duration {
    time - start
}

pub fn unix_to_naivetime(unix_timestamp: i64) -> Option<NaiveTime> {
    if let Some(date_time) = NaiveDateTime::from_timestamp_millis(unix_timestamp) {
        Some(date_time.time())
    } else {
        None
    }
}

pub fn is_same_day(time_1: NaiveTime, time_2: NaiveTime) -> bool {
    time_1.format("%Y:%m:%d").to_string() == time_2.format("%Y:%m:%d").to_string()
}

pub fn unix_to_human_date_time(unix_timestamp: i64) -> String {
    if let Some(date_time) = NaiveDateTime::from_timestamp_opt(unix_timestamp, 0) {
        date_time.format("%b %d, %Y %I:%M %P").to_string()
    } else {
        "Unknown date & time".to_owned()
    }
}

pub fn unix_to_human_date(unix_timestamp: i64) -> String {
    if let Some(date_time) = NaiveDateTime::from_timestamp_opt(unix_timestamp, 0) {
        date_time.format("%b %d, %Y").to_string()
    } else {
        "Unknown date".to_owned()
    }
}

pub fn unix_to_human_time(unix_timestamp: i64) -> String {
    if let Some(date_time) = NaiveDateTime::from_timestamp_opt(unix_timestamp, 0) {
        date_time.format("%I:%M %P").to_string()
    } else {
        "Unknown time".to_owned()
    }
}

pub fn unix_to_machine_date(unix_timestamp: i64) -> String {
    if let Some(date_time) = NaiveDateTime::from_timestamp_opt(unix_timestamp, 0) {
        date_time.format("%F").to_string()
    } else {
        "unknown".to_owned()
    }
}
